@@ -11,7 +11,6 @@
 # under the License.
 
 import sys
-import warnings
 
 from cliff import app
 from cliff import commandmanager
@@ -23,7 +22,7 @@ __version__ = version.version_info.version_string_with_vcs()
 class StestrCLI(app.App):
 
     def __init__(self):
-        super(StestrCLI, self).__init__(
+        super().__init__(
             description="A parallel Python test runner built around subunit",
             version=__version__,
             command_manager=commandmanager.CommandManager('stestr.cm'),
@@ -46,9 +45,8 @@ class StestrCLI(app.App):
             self.LOG.debug('got an error: %s', err)
 
     def build_option_parser(self, description, version, argparse_kwargs=None):
-        parser = super(StestrCLI,
-                       self).build_option_parser(description, version,
-                                                 argparse_kwargs)
+        parser = super().build_option_parser(description, version,
+                                             argparse_kwargs)
         parser = self._set_common_opts(parser)
         return parser
 
@@ -72,7 +70,7 @@ class StestrCLI(app.App):
                                  " is running from is used")
         parser.add_argument('--repo-type', '-r', dest='repo_type',
                             choices=['file', 'sql'], default='file',
-                            help="Select the repo backend to use")
+                            help="DEPRECATED: Select the repo backend to use")
         parser.add_argument('--repo-url', '-u', dest='repo_url',
                             default=None,
                             help="Set the repo url to use. An acceptable value"
@@ -108,12 +106,6 @@ class StestrCLI(app.App):
 
 
 def main(argv=sys.argv[1:]):
-    if sys.version_info[:2] == (2, 7):
-        msg = (
-            "Python 2.7 will reach the end of its life on January 1st, 2020. "
-            "Support for using python 2.7 with stestr will be removed in the "
-            "3.0.0 release in early 2020")
-        warnings.warn(msg, DeprecationWarning, stacklevel=2)
     cli = StestrCLI()
     return cli.run(argv)
 
